==> ah-form-builder-sample-0.6.20.tgz: package/es/utils/file-upload/index.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/utils/file-upload/index.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useRef } from 'react';
import { InputLabel, Typography, Button, Box, LinearProgress } from "@material-ui/core";
import './style.scss';
import FormHelperText from "@material-ui/core/FormHelperText";
import axios from 'axios';
import { fileListToArray } from '../helpers';
import { makeStyles } from "@material-ui/core/styles";
var useStyles = makeStyles(function (theme) {
  return {
    highlight: {
      border: '2px dashed',
      borderColor: theme.palette.primary.main
    }
  };
});

function LinearProgressWithLabel(props) {
  return /*#__PURE__*/React.createElement(Box, {
    display: "flex",
    alignItems: "center",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 18,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(Box, {
    width: "100%",
    mr: 1,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 19,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(LinearProgress, _extends({
    variant: "determinate",
    style: {
      height: 10
    }
  }, props, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 20,
      columnNumber: 9
    }
  }))), /*#__PURE__*/React.createElement(Box, {
    minWidth: 35,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 22,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "body2",
    color: "textSecondary",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 23,
      columnNumber: 9
    }
  }, Math.round(props.value) + "%")));
}

export default function FileUpload(props) {
  var _this = this;

  var fileUploader = useRef(null);

  var _React$useState = React.useState(false),
      highlight = _React$useState[0],
      setHightlight = _React$useState[1];

  var _React$useState2 = React.useState(false),
      uploading = _React$useState2[0],
      setUploading = _React$useState2[1];

  var _React$useState3 = React.useState(null),
      error = _React$useState3[0],
      setError = _React$useState3[1];

  var _React$useState4 = React.useState(0),
      progress = _React$useState4[0],
      setProgress = _React$useState4[1];

  var classes = useStyles();

  var onDragOver = function onDragOver(evt) {
    evt.preventDefault();
    setHightlight(true);
  };

  var onDragLeave = function onDragLeave() {
    setHightlight(false);
  };

  var onDrop = function onDrop(event) {
    event.preventDefault();
    setHightlight(false);

    if (props.uploadable) {
      setUploading(true);
      var files = event.dataTransfer.files;
      uploadFile(files);
    }
  };

  var onFilesAdded = function onFilesAdded(e) {
    if (props.uploadable) {
      setUploading(true);
      var files = e.target.files;
      uploadFile(files);
    }
  };

  var openBrowser = function openBrowser() {
    fileUploader.current.click();
  };

  var validateExtensions = function validateExtensions(file) {
    if (props.variant) {
      var parts = file.name.split('.');
      var extension = parts[parts.length - 1];

      if (props.variant === 'images' && !['jpg', 'jpeg', 'png', 'gif'].includes(extension)) {
        setError('Invalid file format. Please use one of these: jpg, jpeg, png, gif');
        return false;
      } else if (props.variant === 'videos' && !['mp4', 'webm', 'ogg'].includes(extension)) {
        setError('Invalid file format. Please use one of these: mp4, webm, ogg');
        return false;
      }
    }

    return true;
  };

  var uploadFile = function uploadFile(files) {
    setError(null);
    var array = fileListToArray(files);

    if (array.length > 1) {
      setError('Only one file is allowed');
    } else {
      if (validateExtensions(array[0])) {
        var config = {
          onUploadProgress: function onUploadProgress(progressEvent) {
            return setProgress(Math.round(progressEvent.loaded * 100 / progressEvent.total));
          }
        };
        var formData = new FormData();
        formData.append('file', array[0]);
        formData.append('provider', 'true');
        axios.post(props.fileUploadUrl, formData, config).then(function (res) {
          props.updateUrl(res.data.path);
          setUploading(false);
          setProgress(0);
        })["catch"](function (err) {
          if (err.response.status) {
            setError('Invalid file format');
          } else {
            setError('Unable to upload file, try again later');
          }

          setUploading(false);
          setProgress(0);
        });
      } else {
        setUploading(false);
        setProgress(0);
      }
    }
  };

  var renderImage = function renderImage() {
    if (props.url && props.url !== '') {
      return /*#__PURE__*/React.createElement("img", {
        src: props.url,
        className: "width-full file-upload-preview",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 122,
          columnNumber: 9
        }
      });
    } else {
      return /*#__PURE__*/React.createElement("img", {
        src: "https://cdn1.iconfinder.com/data/icons/hawcons/32/698394-icon-130-cloud-upload-512.png",
        width: "100",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 126,
          columnNumber: 9
        }
      });
    }
  };

  var renderVideo = function renderVideo() {
    if (props.url && props.url !== '') {
      return /*#__PURE__*/React.createElement("video", {
        className: "width-full file-upload-preview",
        controls: true,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 134,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("source", {
        src: props.url,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 135,
          columnNumber: 11
        }
      }));
    } else {
      return /*#__PURE__*/React.createElement("img", {
        src: "https://cdn1.iconfinder.com/data/icons/hawcons/32/698394-icon-130-cloud-upload-512.png",
        width: "100",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 140,
          columnNumber: 9
        }
      });
    }
  };

  var renderDropzone = function renderDropzone() {
    var className = 'dropzone';

    if (uploading) {
      if (props.url && props.url !== '') {
        className += ' pt-0';
      }

      return /*#__PURE__*/React.createElement("div", {
        className: className,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 152,
          columnNumber: 9
        }
      }, props.variant === 'images' ? renderImage() : renderVideo(), /*#__PURE__*/React.createElement("div", {
        className: "width-full pl-3 pr-2 pt-3",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 156,
          columnNumber: 11
        }
      }, /*#__PURE__*/React.createElement(LinearProgressWithLabel, {
        value: progress,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 157,
          columnNumber: 13
        }
      })));
    } else {
      if (props.url && props.url !== '') {
        className += ' pt-0';
      }

      if (highlight) {
        className += ' ' + classes.highlight;
      }

      return /*#__PURE__*/React.createElement("div", {
        className: className,
        onDragOver: onDragOver,
        onDragLeave: onDragLeave,
        onDrop: onDrop,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 169,
          columnNumber: 9
        }
      }, props.variant === 'images' ? renderImage() : renderVideo(), /*#__PURE__*/React.createElement(Typography, {
        variant: "h6",
        className: "dropzone-label",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 176,
          columnNumber: 11
        }
      }, props.placeholder ? props.placeholder : 'Drag and drop files here'), /*#__PURE__*/React.createElement(InputLabel, {
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 177,
          columnNumber: 11
        }
      }, "or"), /*#__PURE__*/React.createElement(Button, {
        variant: "outlined",
        color: "primary",
        onClick: openBrowser,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 178,
          columnNumber: 11
        }
      }, props.url && props.url !== '' ? 'Replace File' : 'Browse Files'));
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 185,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(InputLabel, {
    required: props.required,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 186,
      columnNumber: 7
    }
  }, props.label), /*#__PURE__*/React.createElement("input", {
    type: "file",
    id: "file",
    multiple: !!props.isMultiple,
    ref: fileUploader,
    className: "hidden",
    onChange: onFilesAdded,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 187,
      columnNumber: 7
    }
  }), renderDropzone(), /*#__PURE__*/React.createElement(FormHelperText, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 189,
      columnNumber: 7
    }
  }, props.helperText), error ? /*#__PURE__*/React.createElement(FormHelperText, {
    error: true,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 191,
      columnNumber: 9
    }
  }, error) : "");
}

==> ah-form-builder-sample-0.6.85.tgz: package/es/utils/file-upload/index.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/utils/file-upload/index.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useRef } from 'react';
import { InputLabel, Typography, Button, Box, LinearProgress } from "@material-ui/core";
import './style.scss';
import FormHelperText from "@material-ui/core/FormHelperText";
import axios from 'axios';
import { fileListToArray } from '../helpers';
import { makeStyles } from "@material-ui/core/styles";
import { connect } from "react-redux";
var dragAndDrop = {
  en: 'Drag and drop files here',
  ar: 'السحب والإفلات هنا'
};
var or = {
  en: 'or',
  ar: 'أو'
};
var browseFiles = {
  en: 'Browse Files',
  ar: 'تصفح ملفات'
};
var replaceFiles = {
  en: 'Replace Files',
  ar: 'استبدال الملفات'
};
var useStyles = makeStyles(function (theme) {
  return {
    highlight: {
      border: '2px dashed',
      borderColor: theme.palette.primary.main
    }
  };
});

function LinearProgressWithLabel(props) {
  return /*#__PURE__*/React.createElement(Box, {
    display: "flex",
    alignItems: "center",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 36,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(Box, {
    width: "100%",
    mr: 1,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 37,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(LinearProgress, _extends({
    variant: "determinate",
    style: {
      height: 10
    }
  }, props, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 38,
      columnNumber: 9
    }
  }))), /*#__PURE__*/React.createElement(Box, {
    minWidth: 35,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 40,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "body2",
    color: "textSecondary",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 41,
      columnNumber: 9
    }
  }, Math.round(props.value) + "%")));
}

function FileUpload(props) {
  var _this = this;

  var fileUploader = useRef(null);

  var _React$useState = React.useState(false),
      highlight = _React$useState[0],
      setHightlight = _React$useState[1];

  var _React$useState2 = React.useState(false),
      uploading = _React$useState2[0],
      setUploading = _React$useState2[1];

  var _React$useState3 = React.useState(null),
      error = _React$useState3[0],
      setError = _React$useState3[1];

  var _React$useState4 = React.useState(0),
      progress = _React$useState4[0],
      setProgress = _React$useState4[1];

  var classes = useStyles();

  var onDragOver = function onDragOver(evt) {
    evt.preventDefault();
    setHightlight(true);
  };

  var onDragLeave = function onDragLeave() {
    setHightlight(false);
  };

  var onDrop = function onDrop(event) {
    event.preventDefault();
    setHightlight(false);

    if (props.uploadable) {
      setUploading(true);
      var files = event.dataTransfer.files;
      uploadFile(files);
    }
  };

  var onFilesAdded = function onFilesAdded(e) {
    if (props.uploadable) {
      setUploading(true);
      var files = e.target.files;
      uploadFile(files);
    }
  };

  var openBrowser = function openBrowser() {
    fileUploader.current.click();
  };

  var validateExtensions = function validateExtensions(file) {
    if (props.variant) {
      var parts = file.name.split('.');
      var extension = parts[parts.length - 1];

      if (props.variant === 'images' && !['jpg', 'jpeg', 'png', 'gif', 'JPG', 'PNG', 'GIF', 'JPEG'].includes(extension)) {
        setError('Invalid file format. Please use one of these: jpg, jpeg, png, gif');
        return false;
      } else if (props.variant === 'videos' && !['mp4', 'webm', 'ogg', 'MP4', 'WEBM', 'OGG'].includes(extension)) {
        setError('Invalid file format. Please use one of these: mp4, webm, ogg');
        return false;
      }
    }

    return true;
  };

  var uploadFile = function uploadFile(files) {
    setError(null);
    var array = fileListToArray(files);

    if (array.length > 1) {
      setError('Only one file is allowed');
    } else {
      if (validateExtensions(array[0])) {
        var config = {
          onUploadProgress: function onUploadProgress(progressEvent) {
            return setProgress(Math.round(progressEvent.loaded * 100 / progressEvent.total));
          }
        };
        var formData = new FormData();
        formData.append('file', array[0]);
        formData.append('provider', 'true');
        axios.post(props.fileUploadUrl, formData, config).then(function (res) {
          props.updateUrl(res.data.path);
          setUploading(false);
          setProgress(0);
        })["catch"](function (err) {
          if (err.response.status) {
            setError('Invalid file format');
          } else {
            setError('Unable to upload file, try again later');
          }

          setUploading(false);
          setProgress(0);
        });
      } else {
        setUploading(false);
        setProgress(0);
      }
    }
  };

  var renderImage = function renderImage() {
    if (props.url && props.url !== '') {
      return /*#__PURE__*/React.createElement("img", {
        src: props.url,
        className: "ahfb-width-full ahfb-file-upload-preview",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 140,
          columnNumber: 9
        }
      });
    } else {
      return /*#__PURE__*/React.createElement("img", {
        src: "https://cdn1.iconfinder.com/data/icons/hawcons/32/698394-icon-130-cloud-upload-512.png",
        width: "100",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 144,
          columnNumber: 9
        }
      });
    }
  };

  var renderVideo = function renderVideo() {
    if (props.url && props.url !== '') {
      return /*#__PURE__*/React.createElement("video", {
        className: "ahfb-width-full ahfb-file-upload-preview",
        controls: true,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 152,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("source", {
        src: props.url,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 153,
          columnNumber: 11
        }
      }));
    } else {
      return /*#__PURE__*/React.createElement("img", {
        src: "https://cdn1.iconfinder.com/data/icons/hawcons/32/698394-icon-130-cloud-upload-512.png",
        width: "100",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 158,
          columnNumber: 9
        }
      });
    }
  };

  var renderDropzone = function renderDropzone() {
    var className = 'ahfb-dropzone';

    if (uploading) {
      if (props.url && props.url !== '') {
        className += ' ahfb-pt-0';
      }

      return /*#__PURE__*/React.createElement("div", {
        className: className,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 170,
          columnNumber: 9
        }
      }, props.variant === 'images' ? renderImage() : renderVideo(), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-width-full ahfb-pl-3 ahfb-pr-2 ahfb-pt-3",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 174,
          columnNumber: 11
        }
      }, /*#__PURE__*/React.createElement(LinearProgressWithLabel, {
        value: progress,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 175,
          columnNumber: 13
        }
      })));
    } else {
      if (props.url && props.url !== '') {
        className += ' ahfb-pt-0';
      }

      if (highlight) {
        className += ' ' + classes.highlight;
      }

      return /*#__PURE__*/React.createElement("div", {
        className: className,
        onDragOver: onDragOver,
        onDragLeave: onDragLeave,
        onDrop: onDrop,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 187,
          columnNumber: 9
        }
      }, props.variant === 'images' ? renderImage() : renderVideo(), /*#__PURE__*/React.createElement(Typography, {
        variant: "h6",
        className: "ahfb-dropzone-label",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 194,
          columnNumber: 11
        }
      }, props.placeholder && props.currentLang === 'en' ? props.placeholder : dragAndDrop[props.currentLang]), /*#__PURE__*/React.createElement(InputLabel, {
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 195,
          columnNumber: 11
        }
      }, or[props.currentLang]), /*#__PURE__*/React.createElement(Button, {
        variant: "outlined",
        color: "primary",
        onClick: openBrowser,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 196,
          columnNumber: 11
        }
      }, props.url && props.url !== '' ? replaceFiles[props.currentLang] : browseFiles[props.currentLang]));
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 203,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(InputLabel, {
    required: props.required,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 204,
      columnNumber: 7
    }
  }, props.label), /*#__PURE__*/React.createElement("input", {
    type: "file",
    id: "file",
    multiple: !!props.isMultiple,
    ref: fileUploader,
    className: "ahfb-hidden",
    onChange: onFilesAdded,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 205,
      columnNumber: 7
    }
  }), renderDropzone(), /*#__PURE__*/React.createElement(FormHelperText, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 207,
      columnNumber: 7
    }
  }, props.helperText), error ? /*#__PURE__*/React.createElement(FormHelperText, {
    error: true,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 209,
      columnNumber: 9
    }
  }, error) : "");
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

export default connect(mapStateToProps, mapDispatchToProps)(FileUpload);
